@@ -37,7 +37,7 @@ gboolean gdk_spawn_on_screen              (GdkScreen             *screen,
 					   GSpawnFlags            flags,
 					   GSpawnChildSetupFunc   child_setup,
 					   gpointer               user_data,
-					   gint                  *child_pid,
+					   GPid                  *child_pid,
 					   GError               **error);
 
 gboolean gdk_spawn_on_screen_with_pipes   (GdkScreen             *screen,
@@ -47,7 +47,7 @@ gboolean gdk_spawn_on_screen_with_pipes   (GdkScreen             *screen,
 					   GSpawnFlags            flags,
 					   GSpawnChildSetupFunc   child_setup,
 					   gpointer               user_data,
-					   gint                  *child_pid,
+					   GPid                  *child_pid,
 					   gint                  *standard_input,
 					   gint                  *standard_output,
 					   gint                  *standard_error,
