@@ -681,9 +681,9 @@ _gtk_im_module_get_default_context_id (GdkWindow *client_window)
 
   /* Check if the certain immodule is set in XSETTINGS.
    */
-  if (GDK_IS_DRAWABLE (client_window))
+  if (GDK_IS_WINDOW (client_window))
     {
-      screen = gdk_drawable_get_screen (GDK_DRAWABLE (client_window));
+      screen = gdk_window_get_screen (client_window);
       settings = gtk_settings_get_for_screen (screen);
       g_object_get (G_OBJECT (settings), "gtk-im-module", &tmp, NULL);
       if (tmp)
