@@ -551,7 +551,7 @@ gtk_scrolled_window_set_hadjustment (GtkScrolledWindow *scrolled_window,
   if (!priv->hscrollbar)
     {
       gtk_widget_push_composite_child ();
-      priv->hscrollbar = gtk_hscrollbar_new (hadjustment);
+      priv->hscrollbar = gtk_scrollbar_new (GTK_ORIENTATION_HORIZONTAL, hadjustment);
       gtk_widget_set_composite_name (priv->hscrollbar, "hscrollbar");
       gtk_widget_pop_composite_child ();
 
@@ -582,7 +582,7 @@ gtk_scrolled_window_set_hadjustment (GtkScrolledWindow *scrolled_window,
 
   child = gtk_bin_get_child (bin);
   if (GTK_IS_SCROLLABLE (child))
-    gtk_scrollable_set_vadjustment (GTK_SCROLLABLE (child), hadjustment);
+    gtk_scrollable_set_hadjustment (GTK_SCROLLABLE (child), hadjustment);
 
   g_object_notify (G_OBJECT (scrolled_window), "hadjustment");
 }
@@ -614,7 +614,7 @@ gtk_scrolled_window_set_vadjustment (GtkScrolledWindow *scrolled_window,
   if (!priv->vscrollbar)
     {
       gtk_widget_push_composite_child ();
-      priv->vscrollbar = gtk_vscrollbar_new (vadjustment);
+      priv->vscrollbar = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, vadjustment);
       gtk_widget_set_composite_name (priv->vscrollbar, "vscrollbar");
       gtk_widget_pop_composite_child ();
 
@@ -1444,6 +1444,27 @@ gtk_scrolled_window_relative_allocation (GtkWidget     *widget,
     }
 }
 
+static void
+gtk_scrolled_window_allocate_child (GtkScrolledWindow *swindow,
+				    GtkAllocation     *relative_allocation)
+{
+  GtkWidget     *widget = GTK_WIDGET (swindow), *child;
+  GtkAllocation  allocation;
+  GtkAllocation  child_allocation;
+
+  child = gtk_bin_get_child (GTK_BIN (widget));
+
+  gtk_widget_get_allocation (widget, &allocation);
+
+  gtk_scrolled_window_relative_allocation (widget, relative_allocation);
+  child_allocation.x = relative_allocation->x + allocation.x;
+  child_allocation.y = relative_allocation->y + allocation.y;
+  child_allocation.width = relative_allocation->width;
+  child_allocation.height = relative_allocation->height;
+
+  gtk_widget_size_allocate (child, &child_allocation);
+}
+
 static void
 gtk_scrolled_window_size_allocate (GtkWidget     *widget,
 				   GtkAllocation *allocation)
@@ -1460,8 +1481,6 @@ gtk_scrolled_window_size_allocate (GtkWidget     *widget,
   gint sb_width;
   gint sb_height;
  
-
-
   g_return_if_fail (GTK_IS_SCROLLED_WINDOW (widget));
   g_return_if_fail (allocation != NULL);
 
@@ -1491,126 +1510,134 @@ gtk_scrolled_window_size_allocate (GtkWidget     *widget,
   child = gtk_bin_get_child (bin);
   if (child && gtk_widget_get_visible (child))
     {
-      gint child_min_width;
-      gint child_min_height;
+      gint child_scroll_width;
+      gint child_scroll_height;
       gboolean previous_hvis;
       gboolean previous_vvis;
       guint count = 0;
 
-      /* In the case that both scrollbars are visible in the previous round,
-       * we dont do our guess-work before hand because it's possible some
-       * infinite recursion was detected (leave it up to the child scrollable
-       * widget in this case to drive the scrollbar visibility completely 
-       * with the adjustment values).
-       */
-      if (!priv->vscrollbar_visible || !priv->hscrollbar_visible)
+      /* Determine scrollbar visibility first via hfw apis */
+      if (gtk_widget_get_request_mode (child) == GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH)
 	{
-
-	  /* Determine scrollbar visibility first via hfw apis */
-	  if (gtk_widget_get_request_mode (child) == GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH)
+	  if (gtk_scrollable_get_hscroll_policy (GTK_SCROLLABLE (child)) == GTK_SCROLL_MINIMUM)
+	    gtk_widget_get_preferred_width (child, &child_scroll_width, NULL);
+	  else
+	    gtk_widget_get_preferred_width (child, NULL, &child_scroll_width);
+	  
+	  if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
 	    {
-	      gtk_widget_get_preferred_width (child, &child_min_width, NULL);
-	      
-	      if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
-		{
-		  /* First try without a vertical scrollbar if the content will fit the height
-		   * given the extra width of the scrollbar */
-		  gtk_widget_get_preferred_height_for_width (child, allocation->width, 
-							     &child_min_height, NULL);
-		  
-		  if (priv->hscrollbar_policy == GTK_POLICY_AUTOMATIC)
-		    {
-		      /* Does the content height fit the allocation height ? */
-		      priv->vscrollbar_visible = child_min_height > allocation->height;
-		      
-		      /* Does the content width fit the allocation with minus a possible scrollbar ? */
-		      priv->hscrollbar_visible = 
-			child_min_width > allocation->width - 
-			(priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
-		      
-		      /* Now that we've guessed the hscrollbar, does the content height fit
-		       * the possible new allocation height ? */
-		      priv->vscrollbar_visible = 
-			child_min_height > allocation->height - 
-			(priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
-		      
-		      /* Now that we've guessed the vscrollbar, does the content width fit
-		       * the possible new allocation width ? */
-		      priv->hscrollbar_visible = 
-			child_min_width > allocation->width - 
-			(priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
-		    }
-		  else /* priv->hscrollbar_policy != GTK_POLICY_AUTOMATIC */
-		    {
-		      priv->hscrollbar_visible = priv->hscrollbar_policy != GTK_POLICY_NEVER;
-		      priv->vscrollbar_visible = child_min_height > allocation->height - 
-			(priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
-		    }
-		}
-	      else /* priv->vscrollbar_policy != GTK_POLICY_AUTOMATIC */
-		{
-		  priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
-		  
-		  if (priv->hscrollbar_policy == GTK_POLICY_AUTOMATIC)
-		    priv->hscrollbar_visible = 
-		      child_min_width > allocation->width - 
-		      (priv->vscrollbar_visible ? 0 : sb_width + sb_spacing);
-		  else
-		    priv->hscrollbar_visible = priv->hscrollbar_policy != GTK_POLICY_NEVER;
-		}
-	    } 
-	  else /* GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT */
-	    {
-	      gtk_widget_get_preferred_height (child, &child_min_height, NULL);
+	      /* First try without a vertical scrollbar if the content will fit the height
+	       * given the extra width of the scrollbar */
+	      if (gtk_scrollable_get_vscroll_policy (GTK_SCROLLABLE (child)) == GTK_SCROLL_MINIMUM)
+		gtk_widget_get_preferred_height_for_width (child, 
+							   MAX (allocation->width, child_scroll_width), 
+							   &child_scroll_height, NULL);
+	      else
+		gtk_widget_get_preferred_height_for_width (child,
+							   MAX (allocation->width, child_scroll_width), 
+							   NULL, &child_scroll_height);
 	      
 	      if (priv->hscrollbar_policy == GTK_POLICY_AUTOMATIC)
 		{
-		  /* First try without a horizontal scrollbar if the content will fit the width
-		   * given the extra height of the scrollbar */
-		  gtk_widget_get_preferred_width_for_height (child, allocation->height, 
-							     &child_min_width, NULL);
+		  /* Does the content height fit the allocation height ? */
+		  priv->vscrollbar_visible = child_scroll_height > allocation->height;
 		  
-		  if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
-		    {
-		      /* Does the content width fit the allocation width ? */
-		      priv->hscrollbar_visible = child_min_width > allocation->width;
-		      
-		      /* Does the content height fit the allocation with minus a possible scrollbar ? */
-		      priv->vscrollbar_visible = 
-			child_min_height > allocation->height - 
-			(priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
-		      
-		      /* Now that we've guessed the vscrollbar, does the content width fit
-		       * the possible new allocation width ? */
-		      priv->hscrollbar_visible = 
-			child_min_width > allocation->width - 
-			(priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
-		      
-		      /* Now that we've guessed the hscrollbar, does the content height fit
-		       * the possible new allocation height ? */
-		      priv->vscrollbar_visible = 
-			child_min_height > allocation->height - 
-			(priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
-		    }
-		  else /* priv->vscrollbar_policy != GTK_POLICY_AUTOMATIC */
-		    {
-		      priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
-		      priv->hscrollbar_visible = child_min_width > allocation->width - 
-			(priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
-		    }
+		  /* Does the content width fit the allocation with minus a possible scrollbar ? */
+		  priv->hscrollbar_visible = 
+		    child_scroll_width > allocation->width - 
+		    (priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
+		  
+		  /* Now that we've guessed the hscrollbar, does the content height fit
+		   * the possible new allocation height ? */
+		  priv->vscrollbar_visible = 
+		    child_scroll_height > allocation->height - 
+		    (priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
+		  
+		  /* Now that we've guessed the vscrollbar, does the content width fit
+		   * the possible new allocation width ? */
+		  priv->hscrollbar_visible = 
+		    child_scroll_width > allocation->width - 
+		    (priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
 		}
 	      else /* priv->hscrollbar_policy != GTK_POLICY_AUTOMATIC */
 		{
 		  priv->hscrollbar_visible = priv->hscrollbar_policy != GTK_POLICY_NEVER;
-		  
-		  if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
-		    priv->vscrollbar_visible = 
-		      child_min_height > allocation->height - 
-		      (priv->hscrollbar_visible ? 0 : sb_height + sb_spacing);
-		  else
-		    priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
+		  priv->vscrollbar_visible = child_scroll_height > allocation->height - 
+		    (priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
 		}
 	    }
+	  else /* priv->vscrollbar_policy != GTK_POLICY_AUTOMATIC */
+	    {
+	      priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
+	      
+	      if (priv->hscrollbar_policy == GTK_POLICY_AUTOMATIC)
+		priv->hscrollbar_visible = 
+		  child_scroll_width > allocation->width - 
+		  (priv->vscrollbar_visible ? 0 : sb_width + sb_spacing);
+	      else
+		priv->hscrollbar_visible = priv->hscrollbar_policy != GTK_POLICY_NEVER;
+	    }
+	} 
+      else /* GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT */
+	{
+	  if (gtk_scrollable_get_vscroll_policy (GTK_SCROLLABLE (child)) == GTK_SCROLL_MINIMUM)
+	    gtk_widget_get_preferred_height (child, &child_scroll_height, NULL);
+	  else
+	    gtk_widget_get_preferred_height (child, NULL, &child_scroll_height);
+	  
+	  if (priv->hscrollbar_policy == GTK_POLICY_AUTOMATIC)
+	    {
+	      /* First try without a horizontal scrollbar if the content will fit the width
+	       * given the extra height of the scrollbar */
+	      if (gtk_scrollable_get_hscroll_policy (GTK_SCROLLABLE (child)) == GTK_SCROLL_MINIMUM)
+		gtk_widget_get_preferred_width_for_height (child, 
+							   MAX (allocation->height, child_scroll_height), 
+							   &child_scroll_width, NULL);
+	      else
+		gtk_widget_get_preferred_width_for_height (child, 
+							   MAX (allocation->height, child_scroll_height), 
+							   NULL, &child_scroll_width);
+	      
+	      if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
+		{
+		  /* Does the content width fit the allocation width ? */
+		  priv->hscrollbar_visible = child_scroll_width > allocation->width;
+		  
+		  /* Does the content height fit the allocation with minus a possible scrollbar ? */
+		  priv->vscrollbar_visible = 
+		    child_scroll_height > allocation->height - 
+		    (priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
+		  
+		  /* Now that we've guessed the vscrollbar, does the content width fit
+		   * the possible new allocation width ? */
+		  priv->hscrollbar_visible = 
+		    child_scroll_width > allocation->width - 
+		    (priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
+		  
+		  /* Now that we've guessed the hscrollbar, does the content height fit
+		   * the possible new allocation height ? */
+		  priv->vscrollbar_visible = 
+		    child_scroll_height > allocation->height - 
+		    (priv->hscrollbar_visible ? sb_height + sb_spacing : 0);
+		}
+	      else /* priv->vscrollbar_policy != GTK_POLICY_AUTOMATIC */
+		{
+		  priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
+		  priv->hscrollbar_visible = child_scroll_width > allocation->width - 
+		    (priv->vscrollbar_visible ? sb_width + sb_spacing : 0);
+		}
+	    }
+	  else /* priv->hscrollbar_policy != GTK_POLICY_AUTOMATIC */
+	    {
+	      priv->hscrollbar_visible = priv->hscrollbar_policy != GTK_POLICY_NEVER;
+	      
+	      if (priv->vscrollbar_policy == GTK_POLICY_AUTOMATIC)
+		priv->vscrollbar_visible = 
+		  child_scroll_height > allocation->height - 
+		  (priv->hscrollbar_visible ? 0 : sb_height + sb_spacing);
+	      else
+		priv->vscrollbar_visible = priv->vscrollbar_policy != GTK_POLICY_NEVER;
+	    }
 	}
 
       /* Now after guessing scrollbar visibility; fall back on the allocation loop which 
@@ -1619,32 +1646,38 @@ gtk_scrolled_window_size_allocate (GtkWidget     *widget,
        */
       do
 	{
-	  gtk_scrolled_window_relative_allocation (widget, &relative_allocation);
-	  
-	  child_allocation.x = relative_allocation.x + allocation->x;
-	  child_allocation.y = relative_allocation.y + allocation->y;
-	  child_allocation.width = relative_allocation.width;
-	  child_allocation.height = relative_allocation.height;
-
 	  previous_hvis = priv->hscrollbar_visible;
 	  previous_vvis = priv->vscrollbar_visible;
+	  gtk_scrolled_window_allocate_child (scrolled_window, &relative_allocation);
 
-	  gtk_widget_size_allocate (child, &child_allocation);
+	  /* Explicitly force scrollbar visibility checks.
+	   *
+	   * Since we make a guess above, the child might not decide to update the adjustments 
+	   * if they logically did not change since the last configuration
+	   */
+	  if (priv->hscrollbar)
+	    gtk_scrolled_window_adjustment_changed 
+	      (gtk_range_get_adjustment (GTK_RANGE (priv->hscrollbar)), scrolled_window);
+
+	  if (priv->vscrollbar)
+	    gtk_scrolled_window_adjustment_changed 
+	      (gtk_range_get_adjustment (GTK_RANGE (priv->vscrollbar)), scrolled_window);
 
 	  /* If, after the first iteration, the hscrollbar and the
-	   * vscrollbar flip visiblity, then we need both.
+	   * vscrollbar flip visiblity... or if one of the scrollbars flip
+	   * on each itteration indefinitly/infinitely, then we just need both 
+	   * at this size.
 	   */
-	  if (count &&
-	      previous_hvis != priv->hscrollbar_visible &&
-	      previous_vvis != priv->vscrollbar_visible)
+	  if ((count &&
+	       previous_hvis != priv->hscrollbar_visible &&
+	       previous_vvis != priv->vscrollbar_visible) || count > 3)
 	    {
 	      priv->hscrollbar_visible = TRUE;
 	      priv->vscrollbar_visible = TRUE;
 
-	      /* a new resize is already queued at this point,
-	       * so we will immediatedly get reinvoked
-	       */
-	      return;
+	      gtk_scrolled_window_allocate_child (scrolled_window, &relative_allocation);
+
+	      break;
 	    }
 	  
 	  count++;
@@ -1829,7 +1862,7 @@ static void
 gtk_scrolled_window_adjustment_changed (GtkAdjustment *adjustment,
 					gpointer       data)
 {
-  GtkScrolledWindowPrivate *priv;;
+  GtkScrolledWindowPrivate *priv;
   GtkScrolledWindow *scrolled_window;
 
   g_return_if_fail (adjustment != NULL);
@@ -1848,6 +1881,7 @@ gtk_scrolled_window_adjustment_changed (GtkAdjustment *adjustment,
 	  visible = priv->hscrollbar_visible;
 	  priv->hscrollbar_visible = (adjustment->upper - adjustment->lower >
 					      adjustment->page_size);
+
 	  if (priv->hscrollbar_visible != visible)
 	    gtk_widget_queue_resize (GTK_WIDGET (scrolled_window));
 	}
@@ -1862,6 +1896,7 @@ gtk_scrolled_window_adjustment_changed (GtkAdjustment *adjustment,
 	  visible = priv->vscrollbar_visible;
 	  priv->vscrollbar_visible = (adjustment->upper - adjustment->lower >
 					      adjustment->page_size);
+
 	  if (priv->vscrollbar_visible != visible)
 	    gtk_widget_queue_resize (GTK_WIDGET (scrolled_window));
 	}
