@@ -1,7 +1,6 @@
 
 /* Generated data (by glib-mkenums) */
 
-#undef GTK_DISABLE_DEPRECATED
 #include "gtk.h"
 #include "gtkprivate.h"
 
@@ -57,6 +56,7 @@ gtk_assistant_page_type_get_type (void)
             { GTK_ASSISTANT_PAGE_CONFIRM, "GTK_ASSISTANT_PAGE_CONFIRM", "confirm" },
             { GTK_ASSISTANT_PAGE_SUMMARY, "GTK_ASSISTANT_PAGE_SUMMARY", "summary" },
             { GTK_ASSISTANT_PAGE_PROGRESS, "GTK_ASSISTANT_PAGE_PROGRESS", "progress" },
+            { GTK_ASSISTANT_PAGE_CUSTOM, "GTK_ASSISTANT_PAGE_CUSTOM", "custom" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GtkAssistantPageType"), values);
@@ -157,6 +157,21 @@ gtk_cell_renderer_accel_mode_get_type (void)
     return etype;
 }
 
+/* enumerations from "gtkcssprovider.h" */
+GType
+gtk_css_provider_error_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GTK_CSS_PROVIDER_ERROR_FAILED, "GTK_CSS_PROVIDER_ERROR_FAILED", "failed" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GtkCssProviderError"), values);
+    }
+    return etype;
+}
+
 /* enumerations from "gtkdebug.h" */
 GType
 gtk_debug_flag_get_type (void)
@@ -276,6 +291,23 @@ gtk_entry_icon_position_get_type (void)
 }
 
 /* enumerations from "gtkenums.h" */
+GType
+gtk_align_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GTK_ALIGN_FILL, "GTK_ALIGN_FILL", "fill" },
+            { GTK_ALIGN_START, "GTK_ALIGN_START", "start" },
+            { GTK_ALIGN_END, "GTK_ALIGN_END", "end" },
+            { GTK_ALIGN_CENTER, "GTK_ALIGN_CENTER", "center" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GtkAlign"), values);
+    }
+    return etype;
+}
+
 GType
 gtk_arrow_placement_get_type (void)
 {
@@ -505,22 +537,6 @@ gtk_message_type_get_type (void)
     return etype;
 }
 
-GType
-gtk_metric_type_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GTK_PIXELS, "GTK_PIXELS", "pixels" },
-            { GTK_INCHES, "GTK_INCHES", "inches" },
-            { GTK_CENTIMETERS, "GTK_CENTIMETERS", "centimeters" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GtkMetricType"), values);
-    }
-    return etype;
-}
-
 GType
 gtk_movement_step_get_type (void)
 {
@@ -785,6 +801,8 @@ gtk_state_type_get_type (void)
             { GTK_STATE_PRELIGHT, "GTK_STATE_PRELIGHT", "prelight" },
             { GTK_STATE_SELECTED, "GTK_STATE_SELECTED", "selected" },
             { GTK_STATE_INSENSITIVE, "GTK_STATE_INSENSITIVE", "insensitive" },
+            { GTK_STATE_INCONSISTENT, "GTK_STATE_INCONSISTENT", "inconsistent" },
+            { GTK_STATE_FOCUSED, "GTK_STATE_FOCUSED", "focused" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GtkStateType"), values);
@@ -1112,51 +1130,92 @@ gtk_size_request_mode_get_type (void)
 }
 
 GType
-gtk_wrap_allocation_mode_get_type (void)
+gtk_scrollable_policy_get_type (void)
 {
     static GType etype = 0;
     if (G_UNLIKELY(etype == 0)) {
         static const GEnumValue values[] = {
-            { GTK_WRAP_ALLOCATE_FREE, "GTK_WRAP_ALLOCATE_FREE", "free" },
-            { GTK_WRAP_ALLOCATE_ALIGNED, "GTK_WRAP_ALLOCATE_ALIGNED", "aligned" },
-            { GTK_WRAP_ALLOCATE_HOMOGENEOUS, "GTK_WRAP_ALLOCATE_HOMOGENEOUS", "homogeneous" },
+            { GTK_SCROLL_MINIMUM, "GTK_SCROLL_MINIMUM", "minimum" },
+            { GTK_SCROLL_NATURAL, "GTK_SCROLL_NATURAL", "natural" },
             { 0, NULL, NULL }
         };
-        etype = g_enum_register_static (g_intern_static_string ("GtkWrapAllocationMode"), values);
+        etype = g_enum_register_static (g_intern_static_string ("GtkScrollablePolicy"), values);
     }
     return etype;
 }
 
 GType
-gtk_wrap_box_spreading_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GTK_WRAP_BOX_SPREAD_START, "GTK_WRAP_BOX_SPREAD_START", "start" },
-            { GTK_WRAP_BOX_SPREAD_END, "GTK_WRAP_BOX_SPREAD_END", "end" },
-            { GTK_WRAP_BOX_SPREAD_EVEN, "GTK_WRAP_BOX_SPREAD_EVEN", "even" },
-            { GTK_WRAP_BOX_SPREAD_EXPAND, "GTK_WRAP_BOX_SPREAD_EXPAND", "expand" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GtkWrapBoxSpreading"), values);
-    }
-    return etype;
-}
-
-GType
-gtk_wrap_box_packing_get_type (void)
+gtk_state_flags_get_type (void)
 {
     static GType etype = 0;
     if (G_UNLIKELY(etype == 0)) {
         static const GFlagsValue values[] = {
-            { GTK_WRAP_BOX_H_EXPAND, "GTK_WRAP_BOX_H_EXPAND", "h-expand" },
-            { GTK_WRAP_BOX_H_FILL, "GTK_WRAP_BOX_H_FILL", "h-fill" },
-            { GTK_WRAP_BOX_V_EXPAND, "GTK_WRAP_BOX_V_EXPAND", "v-expand" },
-            { GTK_WRAP_BOX_V_FILL, "GTK_WRAP_BOX_V_FILL", "v-fill" },
+            { GTK_STATE_FLAG_ACTIVE, "GTK_STATE_FLAG_ACTIVE", "active" },
+            { GTK_STATE_FLAG_PRELIGHT, "GTK_STATE_FLAG_PRELIGHT", "prelight" },
+            { GTK_STATE_FLAG_SELECTED, "GTK_STATE_FLAG_SELECTED", "selected" },
+            { GTK_STATE_FLAG_INSENSITIVE, "GTK_STATE_FLAG_INSENSITIVE", "insensitive" },
+            { GTK_STATE_FLAG_INCONSISTENT, "GTK_STATE_FLAG_INCONSISTENT", "inconsistent" },
+            { GTK_STATE_FLAG_FOCUSED, "GTK_STATE_FLAG_FOCUSED", "focused" },
             { 0, NULL, NULL }
         };
-        etype = g_flags_register_static (g_intern_static_string ("GtkWrapBoxPacking"), values);
+        etype = g_flags_register_static (g_intern_static_string ("GtkStateFlags"), values);
+    }
+    return etype;
+}
+
+GType
+gtk_region_flags_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GFlagsValue values[] = {
+            { GTK_REGION_EVEN, "GTK_REGION_EVEN", "even" },
+            { GTK_REGION_ODD, "GTK_REGION_ODD", "odd" },
+            { GTK_REGION_FIRST, "GTK_REGION_FIRST", "first" },
+            { GTK_REGION_LAST, "GTK_REGION_LAST", "last" },
+            { GTK_REGION_SORTED, "GTK_REGION_SORTED", "sorted" },
+            { 0, NULL, NULL }
+        };
+        etype = g_flags_register_static (g_intern_static_string ("GtkRegionFlags"), values);
+    }
+    return etype;
+}
+
+GType
+gtk_junction_sides_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GFlagsValue values[] = {
+            { GTK_JUNCTION_NONE, "GTK_JUNCTION_NONE", "none" },
+            { GTK_JUNCTION_CORNER_TOPLEFT, "GTK_JUNCTION_CORNER_TOPLEFT", "corner-topleft" },
+            { GTK_JUNCTION_CORNER_TOPRIGHT, "GTK_JUNCTION_CORNER_TOPRIGHT", "corner-topright" },
+            { GTK_JUNCTION_CORNER_BOTTOMLEFT, "GTK_JUNCTION_CORNER_BOTTOMLEFT", "corner-bottomleft" },
+            { GTK_JUNCTION_CORNER_BOTTOMRIGHT, "GTK_JUNCTION_CORNER_BOTTOMRIGHT", "corner-bottomright" },
+            { GTK_JUNCTION_TOP, "GTK_JUNCTION_TOP", "top" },
+            { GTK_JUNCTION_BOTTOM, "GTK_JUNCTION_BOTTOM", "bottom" },
+            { GTK_JUNCTION_LEFT, "GTK_JUNCTION_LEFT", "left" },
+            { GTK_JUNCTION_RIGHT, "GTK_JUNCTION_RIGHT", "right" },
+            { 0, NULL, NULL }
+        };
+        etype = g_flags_register_static (g_intern_static_string ("GtkJunctionSides"), values);
+    }
+    return etype;
+}
+
+GType
+gtk_border_style_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GTK_BORDER_STYLE_NONE, "GTK_BORDER_STYLE_NONE", "none" },
+            { GTK_BORDER_STYLE_SOLID, "GTK_BORDER_STYLE_SOLID", "solid" },
+            { GTK_BORDER_STYLE_INSET, "GTK_BORDER_STYLE_INSET", "inset" },
+            { GTK_BORDER_STYLE_OUTSET, "GTK_BORDER_STYLE_OUTSET", "outset" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GtkBorderStyle"), values);
     }
     return etype;
 }
@@ -1292,7 +1351,6 @@ gtk_image_type_get_type (void)
     if (G_UNLIKELY(etype == 0)) {
         static const GEnumValue values[] = {
             { GTK_IMAGE_EMPTY, "GTK_IMAGE_EMPTY", "empty" },
-            { GTK_IMAGE_PIXMAP, "GTK_IMAGE_PIXMAP", "pixmap" },
             { GTK_IMAGE_PIXBUF, "GTK_IMAGE_PIXBUF", "pixbuf" },
             { GTK_IMAGE_STOCK, "GTK_IMAGE_STOCK", "stock" },
             { GTK_IMAGE_ICON_SET, "GTK_IMAGE_ICON_SET", "icon-set" },
@@ -1342,23 +1400,6 @@ gtk_notebook_tab_get_type (void)
     return etype;
 }
 
-/* enumerations from "gtkobject.h" */
-GType
-gtk_object_flags_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { GTK_IN_DESTRUCTION, "GTK_IN_DESTRUCTION", "in-destruction" },
-            { GTK_RESERVED_1, "GTK_RESERVED_1", "reserved-1" },
-            { GTK_RESERVED_2, "GTK_RESERVED_2", "reserved-2" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GtkObjectFlags"), values);
-    }
-    return etype;
-}
-
 /* enumerations from "gtkprintoperation.h" */
 GType
 gtk_print_status_get_type (void)
@@ -1433,34 +1474,6 @@ gtk_print_error_get_type (void)
     return etype;
 }
 
-/* enumerations from "gtkprivate.h" */
-GType
-gtk_private_flags_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { PRIVATE_GTK_USER_STYLE, "PRIVATE_GTK_USER_STYLE", "user-style" },
-            { PRIVATE_GTK_RESIZE_PENDING, "PRIVATE_GTK_RESIZE_PENDING", "resize-pending" },
-            { PRIVATE_GTK_HAS_POINTER, "PRIVATE_GTK_HAS_POINTER", "has-pointer" },
-            { PRIVATE_GTK_SHADOWED, "PRIVATE_GTK_SHADOWED", "shadowed" },
-            { PRIVATE_GTK_HAS_SHAPE_MASK, "PRIVATE_GTK_HAS_SHAPE_MASK", "has-shape-mask" },
-            { PRIVATE_GTK_IN_REPARENT, "PRIVATE_GTK_IN_REPARENT", "in-reparent" },
-            { PRIVATE_GTK_DIRECTION_SET, "PRIVATE_GTK_DIRECTION_SET", "direction-set" },
-            { PRIVATE_GTK_DIRECTION_LTR, "PRIVATE_GTK_DIRECTION_LTR", "direction-ltr" },
-            { PRIVATE_GTK_ANCHORED, "PRIVATE_GTK_ANCHORED", "anchored" },
-            { PRIVATE_GTK_CHILD_VISIBLE, "PRIVATE_GTK_CHILD_VISIBLE", "child-visible" },
-            { PRIVATE_GTK_REDRAW_ON_ALLOC, "PRIVATE_GTK_REDRAW_ON_ALLOC", "redraw-on-alloc" },
-            { PRIVATE_GTK_ALLOC_NEEDED, "PRIVATE_GTK_ALLOC_NEEDED", "alloc-needed" },
-            { PRIVATE_GTK_WIDTH_REQUEST_NEEDED, "PRIVATE_GTK_WIDTH_REQUEST_NEEDED", "width-request-needed" },
-            { PRIVATE_GTK_HEIGHT_REQUEST_NEEDED, "PRIVATE_GTK_HEIGHT_REQUEST_NEEDED", "height-request-needed" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GtkPrivateFlags"), values);
-    }
-    return etype;
-}
-
 /* enumerations from "gtkrc.h" */
 GType
 gtk_rc_flags_get_type (void)
@@ -1686,6 +1699,7 @@ gtk_text_search_flags_get_type (void)
         static const GFlagsValue values[] = {
             { GTK_TEXT_SEARCH_VISIBLE_ONLY, "GTK_TEXT_SEARCH_VISIBLE_ONLY", "visible-only" },
             { GTK_TEXT_SEARCH_TEXT_ONLY, "GTK_TEXT_SEARCH_TEXT_ONLY", "text-only" },
+            { GTK_TEXT_SEARCH_CASE_INSENSITIVE, "GTK_TEXT_SEARCH_CASE_INSENSITIVE", "case-insensitive" },
             { 0, NULL, NULL }
         };
         etype = g_flags_register_static (g_intern_static_string ("GtkTextSearchFlags"), values);
@@ -1823,38 +1837,6 @@ gtk_ui_manager_item_type_get_type (void)
 }
 
 /* enumerations from "gtkwidget.h" */
-GType
-gtk_widget_flags_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { GTK_TOPLEVEL, "GTK_TOPLEVEL", "toplevel" },
-            { GTK_NO_WINDOW, "GTK_NO_WINDOW", "no-window" },
-            { GTK_REALIZED, "GTK_REALIZED", "realized" },
-            { GTK_MAPPED, "GTK_MAPPED", "mapped" },
-            { GTK_VISIBLE, "GTK_VISIBLE", "visible" },
-            { GTK_SENSITIVE, "GTK_SENSITIVE", "sensitive" },
-            { GTK_PARENT_SENSITIVE, "GTK_PARENT_SENSITIVE", "parent-sensitive" },
-            { GTK_CAN_FOCUS, "GTK_CAN_FOCUS", "can-focus" },
-            { GTK_HAS_FOCUS, "GTK_HAS_FOCUS", "has-focus" },
-            { GTK_CAN_DEFAULT, "GTK_CAN_DEFAULT", "can-default" },
-            { GTK_HAS_DEFAULT, "GTK_HAS_DEFAULT", "has-default" },
-            { GTK_HAS_GRAB, "GTK_HAS_GRAB", "has-grab" },
-            { GTK_RC_STYLE, "GTK_RC_STYLE", "rc-style" },
-            { GTK_COMPOSITE_CHILD, "GTK_COMPOSITE_CHILD", "composite-child" },
-            { GTK_APP_PAINTABLE, "GTK_APP_PAINTABLE", "app-paintable" },
-            { GTK_RECEIVES_DEFAULT, "GTK_RECEIVES_DEFAULT", "receives-default" },
-            { GTK_DOUBLE_BUFFERED, "GTK_DOUBLE_BUFFERED", "double-buffered" },
-            { GTK_NO_SHOW_ALL, "GTK_NO_SHOW_ALL", "no-show-all" },
-            { GTK_MULTIDEVICE, "GTK_MULTIDEVICE", "multidevice" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GtkWidgetFlags"), values);
-    }
-    return etype;
-}
-
 GType
 gtk_widget_help_type_get_type (void)
 {
