@@ -14,7 +14,6 @@
 *tp++ = gdk_drag_action_get_type();
 *tp++ = gdk_drag_context_get_type();
 *tp++ = gdk_drag_protocol_get_type();
-*tp++ = gdk_drawable_get_type();
 *tp++ = gdk_event_get_type();
 *tp++ = gdk_event_mask_get_type();
 *tp++ = gdk_event_type_get_type();
@@ -43,6 +42,7 @@
 *tp++ = gdk_property_state_get_type();
 *tp++ = gdk_prop_mode_get_type();
 *tp++ = gdk_rectangle_get_type();
+*tp++ = gdk_rgba_get_type();
 *tp++ = gdk_screen_get_type();
 *tp++ = gdk_scroll_direction_get_type();
 *tp++ = gdk_setting_action_get_type();
@@ -51,13 +51,13 @@
 *tp++ = gdk_visual_get_type();
 *tp++ = gdk_visual_type_get_type();
 *tp++ = gdk_window_attributes_type_get_type();
-*tp++ = gdk_window_class_get_type();
 *tp++ = gdk_window_edge_get_type();
+*tp++ = gdk_window_get_type();
 *tp++ = gdk_window_hints_get_type();
-*tp++ = gdk_window_object_get_type();
 *tp++ = gdk_window_state_get_type();
 *tp++ = gdk_window_type_get_type();
 *tp++ = gdk_window_type_hint_get_type();
+*tp++ = gdk_window_window_class_get_type();
 *tp++ = gdk_wm_decoration_get_type();
 *tp++ = gdk_wm_function_get_type();
 *tp++ = gtk_about_dialog_get_type();
@@ -72,6 +72,10 @@
 *tp++ = gtk_adjustment_get_type();
 *tp++ = gtk_align_get_type();
 *tp++ = gtk_alignment_get_type();
+*tp++ = gtk_app_chooser_button_get_type();
+*tp++ = gtk_app_chooser_dialog_get_type();
+*tp++ = gtk_app_chooser_get_type();
+*tp++ = gtk_app_chooser_widget_get_type();
 *tp++ = gtk_application_get_type();
 *tp++ = gtk_arrow_get_type();
 *tp++ = gtk_arrow_placement_get_type();
@@ -82,6 +86,7 @@
 *tp++ = gtk_attach_options_get_type();
 *tp++ = gtk_bin_get_type();
 *tp++ = gtk_border_get_type();
+*tp++ = gtk_border_style_get_type();
 *tp++ = gtk_box_get_type();
 *tp++ = gtk_buildable_get_type();
 *tp++ = gtk_builder_error_get_type();
@@ -113,10 +118,12 @@
 *tp++ = gtk_color_button_get_type();
 *tp++ = gtk_color_selection_dialog_get_type();
 *tp++ = gtk_color_selection_get_type();
-*tp++ = gtk_combo_box_entry_get_type();
 *tp++ = gtk_combo_box_get_type();
+*tp++ = gtk_combo_box_text_get_type();
 *tp++ = gtk_container_get_type();
 *tp++ = gtk_corner_type_get_type();
+*tp++ = gtk_css_provider_error_get_type();
+*tp++ = gtk_css_provider_get_type();
 *tp++ = gtk_debug_flag_get_type();
 *tp++ = gtk_delete_type_get_type();
 *tp++ = gtk_dest_defaults_get_type();
@@ -147,11 +154,12 @@
 *tp++ = gtk_font_selection_dialog_get_type();
 *tp++ = gtk_font_selection_get_type();
 *tp++ = gtk_frame_get_type();
+*tp++ = gtk_gradient_get_type();
+*tp++ = gtk_grid_get_type();
 *tp++ = gtk_handle_box_get_type();
 *tp++ = gtk_hbox_get_type();
 *tp++ = gtk_hbutton_box_get_type();
 *tp++ = gtk_hpaned_get_type();
-*tp++ = gtk_hruler_get_type();
 *tp++ = gtk_hscale_get_type();
 *tp++ = gtk_hscrollbar_get_type();
 *tp++ = gtk_hseparator_get_type();
@@ -177,6 +185,7 @@
 *tp++ = gtk_im_status_style_get_type();
 *tp++ = gtk_info_bar_get_type();
 *tp++ = gtk_invisible_get_type();
+*tp++ = gtk_junction_sides_get_type();
 *tp++ = gtk_justification_get_type();
 *tp++ = gtk_label_get_type();
 *tp++ = gtk_layout_get_type();
@@ -191,7 +200,6 @@
 *tp++ = gtk_menu_tool_button_get_type();
 *tp++ = gtk_message_dialog_get_type();
 *tp++ = gtk_message_type_get_type();
-*tp++ = gtk_metric_type_get_type();
 *tp++ = gtk_misc_get_type();
 *tp++ = gtk_mount_operation_get_type();
 *tp++ = gtk_movement_step_get_type();
@@ -245,13 +253,15 @@
 *tp++ = gtk_recent_manager_error_get_type();
 *tp++ = gtk_recent_manager_get_type();
 *tp++ = gtk_recent_sort_type_get_type();
+*tp++ = gtk_region_flags_get_type();
 *tp++ = gtk_relief_style_get_type();
 *tp++ = gtk_requisition_get_type();
 *tp++ = gtk_resize_mode_get_type();
 *tp++ = gtk_response_type_get_type();
-*tp++ = gtk_ruler_get_type();
 *tp++ = gtk_scale_button_get_type();
 *tp++ = gtk_scale_get_type();
+*tp++ = gtk_scrollable_get_type();
+*tp++ = gtk_scrollable_policy_get_type();
 *tp++ = gtk_scrollbar_get_type();
 *tp++ = gtk_scrolled_window_get_type();
 *tp++ = gtk_scroll_step_get_type();
@@ -273,11 +283,18 @@
 *tp++ = gtk_spin_button_update_policy_get_type();
 *tp++ = gtk_spinner_get_type();
 *tp++ = gtk_spin_type_get_type();
+*tp++ = gtk_state_flags_get_type();
 *tp++ = gtk_state_type_get_type();
 *tp++ = gtk_statusbar_get_type();
 *tp++ = gtk_status_icon_get_type();
+*tp++ = gtk_style_context_get_type();
 *tp++ = gtk_style_get_type();
+*tp++ = gtk_style_properties_get_type();
+*tp++ = gtk_style_provider_get_type();
+*tp++ = gtk_switch_get_type();
+*tp++ = gtk_symbolic_color_get_type();
 *tp++ = gtk_table_get_type();
+*tp++ = gtk_target_entry_get_type();
 *tp++ = gtk_target_flags_get_type();
 *tp++ = gtk_target_list_get_type();
 *tp++ = gtk_tearoff_menu_item_get_type();
@@ -293,6 +310,7 @@
 *tp++ = gtk_text_tag_table_get_type();
 *tp++ = gtk_text_view_get_type();
 *tp++ = gtk_text_window_type_get_type();
+*tp++ = gtk_theming_engine_get_type();
 *tp++ = gtk_toggle_action_get_type();
 *tp++ = gtk_toggle_button_get_type();
 *tp++ = gtk_toggle_tool_button_get_type();
@@ -332,18 +350,14 @@
 *tp++ = gtk_viewport_get_type();
 *tp++ = gtk_volume_button_get_type();
 *tp++ = gtk_vpaned_get_type();
-*tp++ = gtk_vruler_get_type();
 *tp++ = gtk_vscale_get_type();
 *tp++ = gtk_vscrollbar_get_type();
 *tp++ = gtk_vseparator_get_type();
 *tp++ = gtk_widget_get_type();
 *tp++ = gtk_widget_help_type_get_type();
+*tp++ = gtk_widget_path_get_type();
 *tp++ = gtk_window_get_type();
 *tp++ = gtk_window_group_get_type();
 *tp++ = gtk_window_position_get_type();
 *tp++ = gtk_window_type_get_type();
-*tp++ = gtk_wrap_allocation_mode_get_type();
-*tp++ = gtk_wrap_box_get_type();
-*tp++ = gtk_wrap_box_packing_get_type();
-*tp++ = gtk_wrap_box_spreading_get_type();
 *tp++ = gtk_wrap_mode_get_type();
